0.9.9 API documentation: transform2.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
transform2.hpp File Reference

GLM_GTX_transform2 More...

Go to the source code of this file.

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 3, 3, T, Q > | proj2D (mat< 3, 3, T, Q > const &m, vec< 3, T, Q > const &normal)
| Build planar projection matrix along normal axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | proj3D (mat< 4, 4, T, Q > const &m, vec< 3, T, Q > const &normal)
| Build planar projection matrix along normal axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | scaleBias (T scale, T bias)
| Build a scale bias matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | scaleBias (mat< 4, 4, T, Q > const &m, T scale, T bias)
| Build a scale bias matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 3, 3, T, Q > | shearX2D (mat< 3, 3, T, Q > const &m, T y)
| Transforms a matrix with a shearing on X axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | shearX3D (mat< 4, 4, T, Q > const &m, T y, T z)
| Transforms a matrix with a shearing on X axis From GLM_GTX_transform2 extension. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 3, 3, T, Q > | shearY2D (mat< 3, 3, T, Q > const &m, T x)
| Transforms a matrix with a shearing on Y axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | shearY3D (mat< 4, 4, T, Q > const &m, T x, T z)
| Transforms a matrix with a shearing on Y axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | shearZ3D (mat< 4, 4, T, Q > const &m, T x, T y)
| Transforms a matrix with a shearing on Z axis. More...

## Detailed Description

GLM_GTX_transform2

See also
  Core features (dependence)
  GLM_GTX_transform (dependence)

Definition in file transform2.hpp.